@@ -12,7 +12,10 @@ from __future__ import absolute_import, division, print_function, \
     with_statement, unicode_literals
 
 __title__ = 'tmuxp'
-__version__ = '0.1.4'
+__package_name__ = 'tmuxp'
+__version__ = '0.1.5'
+__description__ = 'Manage tmux sessions thru JSON, YAML configs. Features Python API'
+__email__ = 'tony@git-pull.com'
 __author__ = 'Tony Narlock'
 __license__ = 'BSD'
 __copyright__ = 'Copyright 2013 Tony Narlock'
